@@ -1,5 +1,5 @@
 stead = {
-	version = "2.2.3",
+	version = "2.4.1",
 	api_version = "1.1.6", -- last version before 1.2.0
 	table = table,
 	delim = ',',
@@ -15,9 +15,9 @@ stead = {
 	math = math,
 	ticks = instead_ticks,
 	mouse_pos = instead_mouse_pos,
+	mouse_show = instead_mouse_show,
 	finger_pos = instead_finger_pos,
 	mouse_filter = instead_mouse_filter, 
-	menu_toggle = instead_menu_toggle,
 	set_timer = instead_timer,
 	random = instead_random,
 	randomseed = instead_srandom,
@@ -68,6 +68,17 @@ stead = {
 	end
 }
 
+function instead_menu_toggle(n)
+	if n == nil then
+		n = 'main'
+	elseif type(n) ~= 'string' then
+		n = 'toggle'
+	end
+	stead.need_menu = n
+end
+
+stead.menu_toggle = instead_menu_toggle
+
 stead.api_atleast = function(...)
 	local k
 	local v
@@ -75,10 +86,10 @@ stead.api_atleast = function(...)
 		if stead.type(k) ~= 'number' then
 			return false
 		end
-		if not stead.api_version_table[k] or v > stead.api_version_table[k] then
+		if v > (stead.api_version_table[k] or 0) then
 			return false
 		end
-		if v < stead.api_version_table[k] then
+		if v < (stead.api_version_table[k] or 0) then
 			return true
 		end
 	end
@@ -92,10 +103,10 @@ stead.atleast = function(...)
 		if stead.type(k) ~= 'number' then
 			return false
 		end
-		if not stead.version_table[k] or v > stead.version_table[k] then
+		if v > (stead.version_table[k] or 0) then
 			return false
 		end
-		if v < stead.version_table[k] then
+		if v < (stead.version_table[k] or 0) then
 			return true
 		end
 	end
@@ -366,6 +377,10 @@ function txttab(v,a)
 	return iface:tab(v, a)
 end
 
+function txty(v, a)
+	return iface:y(v, a)
+end
+
 function txtj(v)
 	if stead.type(v) ~= 'string' then return nil; end; 
 	return iface:just(v)
@@ -2204,7 +2219,7 @@ stead.game_save = function(self, name, file)
 	h:flush();
 	h:close();
 	game.autosave = false; -- we have only one try for autosave
-	game.restart_game = false
+	stead.restart_game = false
 	return nil;
 end
 
@@ -2237,7 +2252,7 @@ end
 
 game = game {
 	codepage = "UTF-8",
-	nam = "INSTEAD -- Simple Text Adventure interpreter v"..stead.version.." '2009-2015 by Peter Kosyh",
+	nam = "INSTEAD -- Simple Text Adventure interpreter v"..stead.version.." '2009-2016 by Peter Kosyh",
 	dsc = [[
 Commands:^
     look(or just enter), act <on what> (or just what), use <what> [on what], go <where>,^
@@ -3047,6 +3062,12 @@ stead.get_restart = function()
 	return stead.restart_game
 end
 
+stead.get_menu = function()
+	local n = stead.need_menu
+	stead.need_menu = nil
+	return n
+end
+
 stead.restart = function()
 	stead.restart_game = true
 end
@@ -3373,6 +3394,9 @@ end
 
 
 stead.sandbox = function()
+	if STANDALONE then
+		return
+	end
 -- sandbox --
 local check_path = function(realpath, type, find, gsub, savepath, gamepath, path)
 	if not path then
